import pandas as pd

def process_experiment_results(version: str):
    """Loads experiment results, calculates accuracy, reorders columns, and saves to CSV."""
    # Load the experiment results
    df = pd.read_csv(f"../../data/ring/ring.1.{version}.csv")
    # Calculate the accuracy by model and belief
    accuracy_table = df.groupby(["Model", "Belief"])["rationality"].mean().unstack()
    # Reorder the columns in the desired order
    desired_order = ["Given", "Explicit", "Implicit"]
    accuracy_table = accuracy_table.reindex(columns=desired_order)
    # Display the table
    print(f"Accuracy table for version {version}\n")
    print(accuracy_table)
    # Save the table as a CSV file for future use
    accuracy_table.to_csv(f"../../figures/ring/ring_accuracy.1.{version}.csv")

# Process all versions
for version in ["a", "b", "c", "d"]:
    process_experiment_results(version)